@@ -45,6 +45,14 @@ class Chat(CompanyAssetModel):
     chatty_ai_agent: Optional[ChattyAIAgentAssignedToChat] = Field(default=None, description="The id of the chatty ai agent that might or might not be assigned to the chat")
 
     model_config = ConfigDict(extra="ignore")
+
+    @property
+    def has_active_cc(self) -> bool:
+        """
+        Check if a chat has an active continuous conversation.
+        """
+        return any(cc.active for cc in self.continuous_conversations)
+
     def __eq__(self, other: Any) -> bool:
         if not isinstance(other, Chat):
             return False
@@ -246,16 +254,31 @@ class Chat(CompanyAssetModel):
         """Get all sales in the chat"""
         return self.client.sales
 
+    @property
+    def bought_product_ids(self) -> List[StrObjectId]:
+        """Get all sale ids in the chat"""
+        return [sale.product_id for sale in self.sales]
+
     @property
     def products(self) -> List[AssignedAssetToChat]:
         """Get all products in the chat"""
         return self.client.products
 
+    @property
+    def assigned_product_ids(self) -> List[StrObjectId]:
+        """Get all product ids in the chat"""
+        return [product.asset_id for product in self.products]
+
     @property
     def tags(self) -> List[AssignedAssetToChat]:
         """Get all tags in the chat"""
         return self.client.tags
 
+    @property
+    def assigned_tag_ids(self) -> List[StrObjectId]:
+        """Get all tag ids in the chat"""
+        return [tag.asset_id for tag in self.tags]
+
     @property
     def highlights(self) -> List[Highlight]:
         """Get all highlights in the chat"""
@@ -266,6 +289,11 @@ class Chat(CompanyAssetModel):
         """Get all contact points in the chat"""
         return self.client.contact_points
 
+    @property
+    def assigned_source_ids(self) -> List[StrObjectId]:
+        """Get all source ids in the chat"""
+        return [contact_point.source_id for contact_point in self.contact_points]
+
     def get_all_tags(self) -> List[AssignedAssetToChat]:
         """Get all tags in the chat"""
         return self.client.tags
