@@ -1,7 +1,7 @@
-from pydantic import BaseModel, Field
-from typing import List
+from pydantic import Field
+from letschatty.models.base_models.related_asset_mixin import RelatedAssetsMixin
 
-class FAQ(BaseModel):
+class FAQ(RelatedAssetsMixin):
     """FAQ item with question and answer"""
     question: str = Field(..., description="The question")
     answer: str = Field(..., description="The answer to the question")
