@@ -10,9 +10,10 @@ from .chatty_content.content_document import ChattyContentDocument
 from .chatty_content.content_sticker import ChattyContentSticker
 from .chatty_content.content_central import ChattyContentCentral
 from .chatty_content.content_interactive import ChattyContentInteractive
+from .chatty_content.content_button import ChattyContentButton
 from .chatty_context.chatty_context import ChattyContext
 from .chatty_referal.chatty_referal import ChattyReferral
 
 
-ChattyContent : TypeAlias = Union[ChattyContentImage, ChattyContentText, ChattyContentVideo, ChattyContentAudio, ChattyContentReaction, ChattyContentLocation, ChattyContentContacts, ChattyContentDocument, ChattyContentSticker, ChattyContentCentral, ChattyContentInteractive]
+ChattyContent : TypeAlias = Union[ChattyContentImage, ChattyContentText, ChattyContentVideo, ChattyContentAudio, ChattyContentReaction, ChattyContentLocation, ChattyContentContacts, ChattyContentDocument, ChattyContentSticker, ChattyContentCentral, ChattyContentInteractive, ChattyContentButton]
 
