@@ -1,6 +1,8 @@
+from letschatty.models.chat.chat import Chat
 from letschatty.models.company.assets.ai_agents.chatty_ai_agent import ChattyAIAgent
 from letschatty.models.company.assets.ai_agents.chain_of_thought_in_chat import ChainOfThoughtInChatTrigger
 from letschatty.models.company.assets.ai_agents.chatty_ai_mode import ChattyAIMode
+from letschatty.services.ai_agents.relevant_context_picker import RelevantContextPicker
 from letschatty.models.company.empresa import EmpresaModel
 from datetime import datetime
 from zoneinfo import ZoneInfo
@@ -22,7 +24,7 @@ class ContextBuilder:
         return context
 
     @staticmethod
-    def build_context(agent: ChattyAIAgent, mode_in_chat: ChattyAIMode, company_info:EmpresaModel) -> str:
+    def build_context(agent: ChattyAIAgent, mode_in_chat: ChattyAIMode, company_info:EmpresaModel, chat:Chat) -> str:
         if agent.mode == ChattyAIMode.OFF:
             raise ValueError("Agent is in OFF mode, so it can't be used to build context")
         context = f"You are a WhatsApp AI Agent {agent.name} (your agent id is: {agent.id}) for the company {company_info.name}."
@@ -34,22 +36,23 @@ class ContextBuilder:
         context += f"\n\n{ChattyAIMode.get_context_for_mode(mode_in_chat)}"
         context += f"\n\nHere are the context items that will be your knowledge base:"
         for context_item in agent.contexts:
-            context += f"\n\n{context_item.title}: {context_item.content}"
+            if RelevantContextPicker.should_be_used(context_item, chat):
+                context += f"\n\n{context_item.title}: {context_item.content}"
         context += f"\n\nHere are the FAQ:"
         for faq_index, faq in enumerate(agent.faqs):
-            context += f"\n{faq_index + 1}. user: {faq.question}\nAI: {faq.answer}"
-        context += f"\n\nHere are the examples of how you should behave. You can also use them as FAQ. \nNote that the user might be spliting its interaction into multiple messages, so you should be able to handle that and to act the same way, so it resembles a real human conversation."
+            if RelevantContextPicker.should_be_used(faq, chat):
+                context += f"\n{faq_index + 1}. user: {faq.question}\nAI: {faq.answer}"
+        context += f"\n\nHere are the examples of how you should reason based on the user's messages (chain of thought) and answer accordingly. This is the type of reasoning you're expected to do and add to your answer's chain of thought."
         for example_index, example in enumerate(agent.examples):
-            context += f"\n{example_index + 1}. {example.title}\n"
-            for message in example.messages:
-                if message.is_incoming_message:
-                    context += f"\nuser: {message.content.get_body_or_caption()}\n"
-                else:
-                    context += f"\nAI: {message.content.get_body_or_caption()}\n"
+            if RelevantContextPicker.should_be_used(example, chat):
+                context += f"\n{example_index + 1}. {example.title}\n"
+                for element in example.content:
+                    context += f"\n{element.type.value}: {element.content}"
         context += f"\n\nHere are the unbreakable rules you must follow at all times. You can't break them under any circumstances:"
         context += "\nALWAYS prioritize the user experience. If the user is asking for a specific information, you should provide it as long as its within your scope, and then smoothly resume the desired conversation workflow."
         context += "\nNEVER talk about a subject other than the specified in your objective / contexts / prompt. If asked about something else, politely say that that's not within your scope and resume the desired conversation workflow."
-        context += "\nNEVER make up information. If you don't know the answer, say so and explain that you'll escalate the question to a human, then call the human_handover tool."
+        # context += "\nNEVER make up information. If you don't know the answer, say so and explain that you'll escalate the question to a human, then call the human_handover tool."
+
         context += "\nNEVER ask the user for information that you already have."
         context += "\nDo not ask for the user phone number, you're already talking through WhatsApp."
         context += "\nNEVER repeat the same information unless the user asks for it. If you think the user is asking for the same information, try to sumarize it and ask if that suits their needs. If not, offer them to escalate the question to a human and call the human_handover tool."
@@ -58,6 +61,7 @@ class ContextBuilder:
         context += f"\n\nHere are the control triggers you must follow. If you identify any of these situations, you must call the human_handover tool:"
         for trigger in agent.control_triggers:
             context += f"\n{trigger}"
+        context += "If you do call the human_handover tool, ALWAYS send a message to the user explaining that you're escalating the question to a human and that you'll be back soon."
         context += f"\n\nRemember that {ChattyAIMode.get_context_for_mode(mode_in_chat)}"
         if agent.follow_up_strategy is None:
             return context
@@ -70,7 +74,7 @@ class ContextBuilder:
         return context
 
     @staticmethod
-    def build_context_for_follow_up(agent: ChattyAIAgent, mode_in_chat: ChattyAIMode, company_info:EmpresaModel) -> str:
+    def build_context_for_follow_up(agent: ChattyAIAgent, mode_in_chat: ChattyAIMode, company_info:EmpresaModel, chat:Chat) -> str:
         if agent.mode == ChattyAIMode.OFF:
             raise ValueError("Agent is in OFF mode, so it can't be used to build context")
         if agent.follow_up_strategy is None:
@@ -95,7 +99,8 @@ class ContextBuilder:
         context += f"\n\n{ChattyAIMode.get_context_for_mode(mode_in_chat)}"
         context += f"\n\nHere are the context items that will be your knowledge base:"
         for context_item in agent.contexts:
-            context += f"\n\n{context_item.title}: {context_item.content}"
+            if RelevantContextPicker.should_be_used(context_item, chat):
+                context += f"\n\n{context_item.title}: {context_item.content}"
         context += f"\n\nHere are the unbreakable rules you must follow at all times. You can't break them under any circumstances:"
         for rule in agent.unbreakable_rules:
             context += f"\n{rule}"
