@@ -207,11 +207,11 @@ class ChatService:
         return chat.chatty_ai_agent
 
     @staticmethod
-    def add_workflow_link(chat : Chat, link : LinkItem, flow:FlowPreview, execution_context: ExecutionContext, description: str, last_incoming_message_id: Optional[str] = None) -> FlowStateAssignedToChat:
+    def add_workflow_link(chat : Chat, link : LinkItem, flow:FlowPreview, execution_context: ExecutionContext, description: str, last_incoming_message_id: Optional[str] = None, next_call: Optional[datetime] = None) -> FlowStateAssignedToChat:
         """
         Add a tag to the chat.
         """
-        state = FlowStateAssignedToChat.from_link(link, execution_context, description, last_incoming_message_id)
+        state = FlowStateAssignedToChat.from_link(link, execution_context, description, last_incoming_message_id, next_call)
         if state in chat.flow_states:
             raise AssetAlreadyAssigned(f"Flow with id {link.flow_id} already assigned to chat {chat.id}")
         execution_context.set_event_time(state.assigned_at)
@@ -456,7 +456,7 @@ class ChatService:
         Archive a chat.
         """
         if chat.area == Area.ARCHIVED:
-            raise ValueError(f"Chat {chat.id} is already archived")
+            raise AlreadyCompleted(f"Chat {chat.id} is already archived")
         if current_agent and current_agent.id != execution_context.executor.id: #notify the previous agent
             ChatService.add_central_notification_from_text(chat=chat, body=f"El chat fue archivado por {execution_context.executor.name}", subtype=MessageSubtype.CHAT_ARCHIVED)
         else:
@@ -643,7 +643,7 @@ class ChatService:
         Block a chat.
         """
         if chat.area == Area.BLOCKED:
-            raise ValueError(f"Chat {chat.id} is already blocked")
+            raise AlreadyCompleted(f"Chat {chat.id} is already blocked")
         chat.area = Area.BLOCKED
         chat.agent_id = None
         execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
