@@ -87,7 +87,7 @@ class SourceFactory:
         return SourceFactory.instantiate_source(source_data) #type: ignore
 
     @staticmethod
-    def create_new_impure_ad(message: ChattyMessage, company_id: str, default_flow: str | None = None) -> PureAd:
+    def create_new_impure_ad(message: ChattyMessage, company_id: str, whatsapp_default_source: WhatsAppDefaultSource) -> PureAd:
         source_data = {
             "name": f"Anuncio Meta Impuro - {message.referral.source_url}",
             "type": SourceType.PURE_AD,
@@ -95,7 +95,10 @@ class SourceFactory:
             "description": f"El anuncio es impuro porque sólo contiene la url del anuncio (falta el ad_id): {message.referral.source_url}",
             "trackeable": True,
             "meta_ad_url":message.referral.source_url.strip(),
-            "flow": default_flow,
+            "flow": whatsapp_default_source.flow,
+            "tags": whatsapp_default_source.tags,
+            "products": whatsapp_default_source.products,
+            "chatty_ai_agent_config": whatsapp_default_source.chatty_ai_agent_config,
             "company_id": company_id
         }
         return SourceFactory.instantiate_source(source_data) #type: ignore
